#
# spec file for package cosmic-comp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cosmic-comp
Version:        1.0.0~alpha4+0
Release:        1.0.2.1.sr20241202
Summary:        Compositor for the COSMIC DE
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-comp
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xkbcommon)
Requires:       Mesa-libEGL1
Recommends:     Mesa-libGL1

%description
%{summary}.

%prep
%autosetup -a1

%build
%make_build

%install
%make_install
install -d %{buildroot}%{_sysconfdir}/%{name}

%check
%{cargo_test}

%files
%license LICENSE
%{_bindir}/%{name}
%{_sysconfdir}/%{name}
%{_datadir}/cosmic

%changelog
* Thu Dec  5 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * focus: Only consider focused output
  * focus: Un-activate non-active workspaces
  * fix: filter by active workspace in overlap notify
  * shell: Fix windows global geometry to include ssd
  * input: Apply output transform to touch/tablet events
  * input: Define function for transforming touch/tablet event position
  * screencopy: don't force opaque window backgrounds
  * refactor: add namespace
  * overlay-notify: Implement handler
  * overlap-notify: Implementation fixes
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * Add cosmic_atspi_v1 protocol
  * element/window: Input offset fixes
  * toplevel_info: Fix racy data creation
  * kms: Don't substract for mirrored outputs
  * DPMS with wlr-output-power-management-unstable-v1 protocol
  * set cursor shape for resize grabs
  * focus: Fix layer-popup locations
  * input: Use render_input_order
  * render: Use render_input_order
  * focus: Introduce render_input_order
  * Don't create initial empty workspace when there are other workspaces
  * On adding output add set after processing other sets
  * Fix workspace indices when workspace is moved to another output
  * Preserve active workspace when workspaces are moved back to another
    output
  * When moving workspaces on output remove, don't movve empty workspace
  * Fix spelling of prefers
  * Use to_ne_bytes() instead of unsound Vec::from_raw_parts
  * fix(menu): use corner radius from theme
  * Add COSMIC_DISABLE_DIRECT_SCANOUT env var
  * Add util function for boolean env vars
  * cursor follows focus to center of window
  * fix(window): center window title
  * fix(menu): styling
  * use Grabbing cursor instead of Grab cursor
  * input: Treat pointer-shortcuts as potentially inhibited
  * Set default output transform based on DRM panel orientation
  * Update egui, smithay-egui, smithay
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Use EGL_MESA_device_software as fallback for screen capture
  * iced: Set default font
  * Add wl-clipboard to tiling exceptions
  * kms: Try to calculate dpi and scale factor
  * Use fallback scale if size is invalid
  * screencopy: Use buffer age of 0 for render to temporary buffer
  * Add xdg-foreign-unstable-v2 protocol
  * xwayland: Add descaling option
  * added cursor_follows_focus and focus_follows_cursor
  * Use new config from cosmic-settings-config
  * Add config reloading for tiling exceptions
  * Apply suggestions from code review
  * wayland: Implement cursor-shape-v1
  * input: Move actions into own module
  * actions: Fix focus on Output-actions
  * input: Fix passed button events
  * fix: add wayland, x11 libraries in runtime
  * Destroy X11Wm when we lose connect to X server
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * reduce duplication
  * add PlayPause/Prev/Next shortcuts
  * fix round corners
  * add translations
- enable leap (thanks to vyvir)
* Sat Jul  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.1.0+git20240705.11914e9:
  * Use `FromGlesError` instead of `OutputNoMode` placeholder
  * screencopy: Handle error from `with_buffer_contents_mut`
  * shell: Don't check grab-conditions for SSD grabs
  * tiling: Don't crash when swapping with group
  * shell: Populate focus_stack when unstacking
  * focus: Fall back to first window, if stack is empty
  * shell: Don't skip over Group-targets for next_focus
  * chore: smithay update
  * feat: runtime configurable keybindings
  * xwayland: Fix offset x11 geometry after configure request
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
